aioslack
========

AsyncIO library for the Slack API.

[![build status](https://travis-ci.org/jreese/aioslack.svg?branch=master)](https://travis-ci.org/jreese/aioslack)
[![version](https://img.shields.io/pypi/v/aioslack.svg)](https://pypi.org/project/aioslack)
[![license](https://img.shields.io/pypi/l/aioslack.svg)](https://github.com/jreese/aioslack/blob/master/LICENSE)
[![code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


License
-------

aioslack is copyright [John Reese](https://jreese.sh), and licensed under
the MIT license.  I am providing code in this repository to you under an open
source license.  This is my personal repository; the license you receive to
my code is from me and not from my employer. See the `LICENSE` file for details.
